/*
This is a part of the LiteStep Shell Source code.

Copyright (C) 1997-2001 The LiteStep Development Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/ 
/*
  Copyright (C) 1998-1999 Johan Redestig
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/
#if !defined(AFX_POPUPMAKER_H__7375AD76_787E_11D2_B6A7_00C0DF466974__INCLUDED_)
#define AFX_POPUPMAKER_H__7375AD76_787E_11D2_B6A7_00C0DF466974__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#define MAX_RC_STRING 256

#include <vector>

class PopupMenu;
class Painter;
class MenuItem;

class PopupMaker
{
public:
	PopupMaker();
	~PopupMaker();

	void Show(int index = 0);
	void Hide(int index = 0);

	void ShowDesktopMenu();
	void ShowTaskMenu();

	void Initialize(HWND ParentWnd, HINSTANCE dllInst, LPCSTR szPath);

	void ParseStepRC();
	void ParseFolder(FILE *pStepRC, PopupMenu *pRoot);
	BOOL ParseLine(FILE *pStepRC, PopupMenu *pRoot, LPCSTR pszLine);

	PopupMenu *LoadFolder(LPSTR pszTitle, LPSTR pszFolder);

	Painter *MakePainter(LPSTR pszImage, DWORD dwColor, DWORD dwGradColor, BOOL bGrad, BOOL bSwap, int nShadowDepth, DWORD dwShadowColor);

	/**
	Returns a new MenuItem according to pszItem with the pszTitle

	@param pszItem name of the menu item to create
	@param pszTitle the title of the menu item
	@return a new menu item, or NULL if none suitable was found
	*/
	MenuItem* MakeBangItem(LPSTR pszItem, LPSTR pszTitle);

	/**
	Adds a separator to the menu

	@param pMenu menu to add to the separator to
	@return the separator item
	*/
	MenuItem *AddSeparator(PopupMenu *pMenu);

	/**
	adds the bottom image to the menu item. if m_pBottom is not pointing at NULL
	then nothing happens

	@param pMenu pointer to the menu that shall receive a bottom image
	*/
	void AddBottomItem(PopupMenu* pMenu);

	void AddHeaderItem(PopupMenu* pMenu, LPSTR pszTitle, BOOL bVeto);

	//private:

    std::vector<PopupMenu *> m_RootMenus;
    std::vector<Painter*> m_Painters;

	HINSTANCE hInst;

	char m_szHotListName[MAX_RC_STRING];

	int m_nTitleHeight;
	int m_nSubmenuHeight;
	int m_nSeparatorHeight;
	int m_nBottomHeight;

	char m_pszDefaultIcon[MAX_RC_STRING];
    char m_pszFolderIcon[MAX_RC_STRING];
	BOOL m_bIcons;
	int m_nIconSpacing;
	int m_nIconSize;

	BOOL m_bShowExtension;
	BOOL m_bAutoSeparator;
	BOOL m_bFolderArrow;
	BOOL m_bPinnedAlwaysOnTop;

	BOOL m_bHeader;
	BOOL m_bHeaderText;
	BOOL m_bTransparent;

	int m_nDateTimeAlignment;

	HFONT m_hfnTitle;
	HFONT m_hfnEntry;
	HFONT m_hfnFolder;
	HFONT m_hfnSelEntry;
	HFONT m_hfnSelFolder;

	PopupMenu *m_pRoot;
	PopupMenu *m_pDesktopMenu;
	PopupMenu *m_pTaskMenu;

	Painter *m_pBackground;
	Painter *m_pTitle;
	Painter *m_pInactiveTitle;
	Painter *m_pEntry;
	Painter *m_pSelEntry;
	Painter *m_pFolder;
	Painter *m_pSelFolder;
	Painter *m_pSeparator;
	Painter *m_pBottom;

	HBITMAP m_hbmArrow;
	HBITMAP m_hbmSelArrow;
};

#endif // !defined(AFX_POPUPMAKER_H__7375AD76_787E_11D2_B6A7_00C0DF466974__INCLUDED_)
